Module storage_path

Module storage_path 

Canonical decoded paths used by Pubky storage and WebDAV operations.

Structs

StoragePath
A canonical decoded Pubky storage path that can be encoded as an HTTP/WebDAV URI path.

Enums

StoragePathError
Error validating or normalizing a StoragePath.

Constants

MAX_STORAGE_PATH_SEGMENT_LENGTH
Maximum decoded UTF-8 byte length of one path segment.
MAX_STORAGE_PATH_TOTAL_LENGTH
Maximum decoded UTF-8 byte length of a complete canonical path.