pub enum StoragePathError {
NotAbsolute,
EmptySegment,
CurrentDirectorySegment,
ParentDirectorySegment,
TraversalAboveRoot,
ControlCharacter,
Backslash,
TrailingWhitespace,
SegmentTooLong {
actual: usize,
maximum: usize,
},
PathTooLong {
actual: usize,
maximum: usize,
},
}Expand description
Error validating or normalizing a StoragePath.
Variants
NotAbsolute
The path does not begin with /.
EmptySegment
The path contains an empty segment such as //.
CurrentDirectorySegment
The path contains a . segment.
ParentDirectorySegment
The path contains a .. segment.
TraversalAboveRoot
Normalization would traverse above root.
ControlCharacter
A segment contains a Unicode control character.
Backslash
A segment contains a backslash, which is a path separator on some platforms.
TrailingWhitespace
The complete path ends in Unicode whitespace.
SegmentTooLong
A decoded segment exceeds the byte limit.
Fields
PathTooLong
The complete decoded path exceeds the byte limit.