Pubky Common
Common structs and functions shared between client (pubky crate) and server (pubky-homeserver crate).
Re-exports
pub use storage_path::StoragePath;pub use storage_path::StoragePathError;
Modules
- auth
- Authentication types shared between homeserver and SDK.
- capabilities
- Capabilities define what a bearer can access (a scoped path) and how (a set of actions).
- constants
- Constants used across Pubky.
- crypto
- Cryptographic functions (hashing, encryption, and signatures).
- events
- Event types shared across Pubky crates.
- namespaces
- Namespaces using to prepend signed messages to avoid collisions.
- recovery_
file - Tools for encrypting and decrypting a recovery file storing user’s root key’s secret.
- session
- Pubky homeserver session types.
- storage_
path - Canonical decoded paths used by Pubky storage and WebDAV operations.
- timestamp
- Timestamp used across Pubky crates.