pub struct StoragePath(/* private fields */);Expand description
A canonical decoded Pubky storage path that can be encoded as an HTTP/WebDAV URI path.
Percent signs are literal. URL decoding must happen before construction. Paths cannot end in whitespace because storage backends may trim it.
Implementations
Sourceimpl StoragePath
impl StoragePath
Sourcepub fn new(path: &str) -> Result<Self, StoragePathError>
pub fn new(path: &str) -> Result<Self, StoragePathError>
Parse an already-canonical decoded absolute path.
Sourcepub fn normalize(path: &str) -> Result<Self, StoragePathError>
pub fn normalize(path: &str) -> Result<Self, StoragePathError>
Normalize a decoded absolute HTTP/WebDAV path and validate the result.
Sourcepub fn is_directory(&self) -> bool
pub fn is_directory(&self) -> bool
Return whether this path is directory-shaped.
Sourcepub fn url_encode(&self) -> String
pub fn url_encode(&self) -> String
Encode this decoded path for use as an HTTP URL path.